@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2015-04-09'; # DATE
-our $VERSION = '1.49'; # VERSION
+our $DATE = '2015-04-11'; # DATE
+our $VERSION = '1.50'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -218,6 +218,10 @@ sub BUILD {
             $copts->{config_profile} = { $_t->('config_profile') };
         }
 
+        if ($self->read_env) {
+            $copts->{no_env} = { $_t->('no_env') };
+        }
+
         if ($self->log) {
             $copts->{log_level} = { $_t->('log_level'), };
             $copts->{trace}     = { $_t->('trace'), };
@@ -745,7 +749,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.49 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-04-09.
+This document describes version 1.50 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-04-11.
 
 =head1 SYNOPSIS
 
